@@ -9,6 +9,7 @@ from collections import defaultdict
 from datetime import datetime
 
 import aiohttp
+import dbus_next
 import dyne.org.funtoo.powerbus as powerbus
 from bson.json_util import CANONICAL_JSON_OPTIONS, loads
 from dbus_next import Message, InterfaceNotFoundError, BusType
@@ -65,7 +66,10 @@ async def get_session_inhibitor(inhibitor_obj_path):
 	bus_name = "org.gnome.SessionManager"
 	introspection = await bus.introspect(bus_name, inhibitor_obj_path)
 	obj = bus.get_proxy_object(bus_name, inhibitor_obj_path, introspection)
-	iface = obj.get_interface("org.gnome.SessionManager.Inhibitor")
+	try:
+		iface = obj.get_interface("org.gnome.SessionManager.Inhibitor")
+	except dbus_next.errors.InterfaceNotFoundError:
+		return None, None
 	bitwise_flags = await iface.call_get_flags()
 	kinds = set()
 	if bitwise_flags & 4 != 0:
