@@ -22,6 +22,10 @@ LID_LAST_OPENED = None
 import dyne.org.funtoo.powerbus as powerbus
 
 
+# TODO: handle scenario where lid is already closed, and AC adapter unplugged. Grab AC event and then
+#       do an accelerated sleep?
+
+
 def get_file(fn):
 	"""
 	A simple method to retrieve the contents of a file, or return None if the file does not exist.
@@ -469,6 +473,7 @@ class PowerBusDaemon(object):
 			if not on_ac_power():
 				self.last_maybe_accelerated_sleep = get_utc_time()
 				self.lid_closed_accelerated_sleep = True
+				logging.warning("We might go to sleep due to lid closed!")
 
 	async def state_manager(self):
 		"""
@@ -523,11 +528,14 @@ class PowerBusDaemon(object):
 			#       time of resume. This will prevent a lid-open-but-system-goes-right-back-to-sleep condition.
 
 			if self.has_lid and self.lid_closed_accelerated_sleep:
+				logging.debug("Considering accelerated sleep")
 				# let's really make sure the lid is still closed, and if it's not, let's not try to sleep very soon!
 				if await lid_is_closed():
+					logging.debug("Lid is still closed")
 					# OK, lid is really closed -- so we will try to go to sleep very soon.
 					timeout_ms = self.lid_closed_idle_delay_ms
 				else:
+					logging.debug("Lid closed false alarm!")
 					# False alarm!
 					self.lid_closed_accelerated_sleep = False
 
@@ -552,6 +560,7 @@ class PowerBusDaemon(object):
 				continue
 
 			if self.has_lid and self.lid_closed_accelerated_sleep:
+				logging.debug("Prepping for accelerated sleep")
 				# We are about to sleep, and this is an "accelerated" sleep due to the lid being closed.
 				# Therefore, update the timestamp for the last accelerated sleep, and also turn off accel.
 				# sleep mode -- it can only be active for one shot, then it gets disabled until the lid is
@@ -560,7 +569,7 @@ class PowerBusDaemon(object):
 				self.lid_closed_accelerated_sleep = False
 			else:
 				self.last_sleep_attempt = get_utc_time()
-
+			logging.debug("Starting sleep!")
 			await self.tell_clients_to_prepare_for_sleep()
 			await asyncio.sleep(0.25)
 			self.go_to_sleep()
@@ -584,9 +593,7 @@ class PowerBusDaemon(object):
 			if val is not None:
 				out_json["times"][key] = str(val)
 		out_json["state"] = str(self.state)
-		out_json["clients"] = []
-		for ckey, datums in self.clients.items():
-			out_json["clients"].append((client_key_to_str(ckey), datums))
+		out_json["clients"] = self.clients
 		out_json["on_ac"] = on_ac_power()
 		out_json["ignore_inhibit"] = powerbus.model.ignore_inhibit
 		out_json["sleep_inhibit"] = await sleep_inhibited()
@@ -646,7 +653,7 @@ class PowerBusDaemon(object):
 			print(f" * Sleep inhibited (session):", self.color(session_inhibit))
 			if session_inhibit:
 				for client_key, inhibitor_dict in inhibitors.items():
-					print(f"   > {self.color(client_key_to_str(client_key))}")
+					print(f"   > {self.color(client_key)}")
 					for app_name, extras in inhibitor_dict.items():
 						print(f"     \\ {app_name} : {extras}")
 			print(colorama.Style.RESET_ALL)
@@ -692,17 +699,7 @@ class PowerBusDaemon(object):
 
 
 def client_key_from_msg(msg_obj):
-	client_key = set()
-	for key in ["USER", "DISPLAY"]:
-		client_key.add((key, msg_obj[key]))
-	return frozenset(client_key)
-
-
-def client_key_to_str(client_key):
-	t = {}
-	for key, val in client_key:
-		t[key] = val
-	return f"{t['USER']}{t['DISPLAY']}"
+	return f"{msg_obj['USER']}{msg_obj['DISPLAY']}"
 
 
 def get_utc_time():
